@@ -17,13 +17,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-gtk-webcore.cpp 3111 2007-03-30 08:18:40Z makeinu $
+ *  $Id: kz-gtk-webcore.cpp 3282 2007-10-15 10:51:03Z ikezoe $
  */
 
+#ifdef HAVE_CONFIG_H
+#  include "config.h"
+#endif /* HAVE_CONFIG_H */
+
 #include <glib/gi18n.h>
 #include <math.h>
-#include <sys/utsname.h>
-#include <osb.h>
 
 #include "kazehakase.h"
 #include "kz-gtk-webcore.h"
@@ -32,8 +34,7 @@
 #include "kz-prompt-dialog.h"
 #include "kz-proxy-item.h"
 #include "gtk-utils.h"
-
-#define GTK_WEBCORE_HAS_MOUSE_DOWN 0
+#include "utils.h"
 
 typedef struct _KzGtkWebcorePrivate	KzGtkWebcorePrivate;
 struct _KzGtkWebcorePrivate
@@ -43,7 +44,9 @@ struct _KzGtkWebcorePrivate
 	gchar *link_message;
 	guint32 button_press_time;
 
-	gboolean  is_loading;
+	gboolean is_loading;
+	gboolean lock;
+	WebiSettings *settings;
 };
 #define KZ_GTK_WEBCORE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), KZ_TYPE_GTK_WEBCORE, KzGtkWebcorePrivate))
 
@@ -70,20 +73,9 @@ static void         kz_gtk_webcore_req_auth_prompt  (Webi     *webi,
 static Webi        *kz_gtk_webcore_req_new_window   (Webi     *webi,
 						     const gchar *url);
 static void         kz_gtk_webcore_close_window     (Webi     *webi);
-static void         kz_gtk_webcore_mouse_over       (Webi        *webi,
-						     const gchar *link_title,
-						     const gchar *link_label,
-						     const gchar *link_url,
-						     const gchar *link_target);
-#if GTK_WEBCORE_HAS_MOUSE_DOWN
-static gboolean     kz_gtk_webcore_mouse_down       (Webi        *webi,
-						     const gchar *link_url,
-						     guint        button);
-static gboolean     kz_gtk_webcore_mouse_up         (Webi        *webi,
-						     const gchar *link_url,
-						     guint        button);
-#endif
+
 static gboolean     kz_gtk_webcore_set_cookie       (Webi       *webi,
+						     const gchar *url,
 						     WebiCookie *cookie);
 /* embed iface */
 static void         kz_gtk_webcore_load_url         (KzEmbed      *kzembed,
@@ -115,6 +107,10 @@ static KzNavi      *kz_gtk_webcore_get_nth_nav_link (KzEmbed      *kzembed,
 static GList       *kz_gtk_webcore_get_nav_links    (KzEmbed      *kzembed,
 						     KzEmbedNavLink link);
 
+static gboolean     kz_gtk_webcore_get_lock         (KzEmbed      *kzembed);
+static void         kz_gtk_webcore_set_lock         (KzEmbed      *kzembed,
+						     gboolean      lock);
+
 static void         kz_gtk_webcore_shistory_get_nth (KzEmbed      *kzembed, 
 						     int           nth,
 						     gboolean      is_relative,
@@ -149,8 +145,6 @@ static gboolean	    kz_gtk_webcore_get_allow_images      (KzEmbed      *kzembed)
 static void	    kz_gtk_webcore_set_allow_images      (KzEmbed      *kzembed,
 							  gboolean      allow);
 /* KzEmbedPrefs interfaces */
-static OSB::Preferences *get_osb_preferences (Webi *webi);
-
 static void          kz_gtk_webcore_prefs_iface_init      (KzEmbedPrefsIFace *iface);
 #if 0
 static gboolean      kz_gtk_webcore_prefs_init	    (KzEmbedPrefs *embed_prefs);
@@ -236,18 +230,13 @@ kz_gtk_webcore_class_init (KzGtkWebcoreClass *klass)
 	gtk_webcore_class->load_stop  = kz_gtk_webcore_load_stop;
 	gtk_webcore_class->location   = kz_gtk_webcore_location;
 	gtk_webcore_class->title      = kz_gtk_webcore_title;
-#if 0	
+#if 0
 	gtk_webcore_class->progress   = kz_gtk_webcore_progress;
-#endif	
+#endif
 	gtk_webcore_class->req_js_prompt   = kz_gtk_webcore_req_js_prompt;
 	gtk_webcore_class->req_auth_prompt = kz_gtk_webcore_req_auth_prompt;
 	gtk_webcore_class->req_new_window  = kz_gtk_webcore_req_new_window;
 	gtk_webcore_class->close_window    = kz_gtk_webcore_close_window;
-	gtk_webcore_class->mouse_over      = kz_gtk_webcore_mouse_over;
-#if GTK_WEBCORE_HAS_MOUSE_DOWN
-	gtk_webcore_class->mouse_down      = kz_gtk_webcore_mouse_down;
-	gtk_webcore_class->mouse_up        = kz_gtk_webcore_mouse_up;
-#endif	
 	gtk_webcore_class->set_cookie      = kz_gtk_webcore_set_cookie;
 
 	g_type_class_add_private (object_class, sizeof(KzGtkWebcorePrivate));
@@ -298,8 +287,8 @@ kz_gtk_webcore_iface_init (KzEmbedIFace *iface)
 	iface->go_history_index       = NULL;
 	iface->do_command             = NULL;
 	iface->can_do_command         = NULL;
-	iface->get_lock               = NULL;
-	iface->set_lock               = NULL;
+	iface->get_lock               = kz_gtk_webcore_get_lock;
+	iface->set_lock               = kz_gtk_webcore_set_lock;
 	iface->get_body_text          = NULL;
 #if 0
 	iface->get_selection_source   = NULL;
@@ -367,8 +356,9 @@ kz_gtk_webcore_prefs_iface_init (KzEmbedPrefsIFace *iface)
 }
 
 static void
-set_font_preferences (KzProfile *profile, OSB::Preferences *preferences)
+set_font_preferences (KzProfile *profile, KzGtkWebcore *gtk_webcore)
 {
+	WebiSettings *settings = KZ_GTK_WEBCORE_GET_PRIVATE(gtk_webcore)->settings;
 	/* font settings */
 	GList *list, *node;
 	gint i = 0;
@@ -446,8 +436,8 @@ set_font_preferences (KzProfile *profile, OSB::Preferences *preferences)
 			kz_profile_get_value(profile, "Font", key,
 					&value, strlen(value)+1,
 					KZ_PROFILE_VALUE_TYPE_STRING);
-			preferences->setSerifFontFamily(value);
-			preferences->setStandardFontFamily(value);
+			settings->serif_font_family = g_strdup(value);
+			settings->standard_font_family = g_strdup(value);
 		}
 		else if (!strcmp(key, sans_font))
 		{
@@ -455,7 +445,7 @@ set_font_preferences (KzProfile *profile, OSB::Preferences *preferences)
 			kz_profile_get_value(profile, "Font", key,
 					&value, strlen(value)+1,
 					KZ_PROFILE_VALUE_TYPE_STRING);
-			preferences->setSansSerifFontFamily(value);
+			settings->sans_serif_font_family = g_strdup(value);
 		}
 		else if (!strcmp(key, mono_font))
 		{
@@ -463,7 +453,7 @@ set_font_preferences (KzProfile *profile, OSB::Preferences *preferences)
 			kz_profile_get_value(profile, "Font", key,
 					&value, strlen(value)+1,
 					KZ_PROFILE_VALUE_TYPE_STRING);
-			preferences->setFixedFontFamily(value);
+			settings->fixed_font_family = g_strdup(value);
 		}
 	}
 	g_list_free(list);
@@ -471,33 +461,24 @@ set_font_preferences (KzProfile *profile, OSB::Preferences *preferences)
 	g_free(sans_font);
 	g_free(mono_font);
 
+	double dpi_pixel_ratio = 72.0 / 96.0;
 	if (size_variable >= 0)
-		preferences->setDefaultFontSize((float)size_variable);
+		settings->default_font_size = (gfloat)(size_variable * dpi_pixel_ratio);
 	if (size_fixed >= 0)
-		preferences->setDefaultFixedFontSize((float)size_fixed);
+		settings->default_fixed_font_size = (gfloat)(size_fixed * dpi_pixel_ratio);
 	if (min_size_variable >= 0)
-		preferences->setMinimumLogicalFontSize((float)min_size_variable);
+		settings->minimum_font_size = (gfloat)(min_size_variable * dpi_pixel_ratio);
 	if (min_size_fixed >= 0)
-		preferences->setMinimumFontSize((float)min_size_fixed);
+		settings->minimum_font_size = (gfloat)(min_size_fixed * dpi_pixel_ratio);
 }
 
 static void
 build_user_agent (gchar *user_agent, gint size)
 {
-	struct utsname name;
 	gchar *system;
 
-	if (uname (&name) >= 0)
-	{
-		system = g_strdup_printf ("%s %s",
-					  name.sysname, 
-					  name.machine);
-	}
-	else
-	{
-		system = g_strdup ("Unknown");
-	}
-		
+	system = kz_utils_get_system_name();
+
 	g_snprintf(user_agent, size,
 		   "Mozilla/5.0 (X11; %s; U;) AppleWebKit/146.1 (KHTML, like Gecko) Kazehakase" VERSION,
 		   system);
@@ -507,6 +488,7 @@ build_user_agent (gchar *user_agent, gint size)
 static void
 set_user_agent (KzProfile *profile, KzGtkWebcore *gtk_webcore)
 {
+	WebiSettings *settings = KZ_GTK_WEBCORE_GET_PRIVATE(gtk_webcore)->settings;
 	gchar tmp_string[1024];
 	gboolean value = FALSE;
 	kz_profile_get_value(profile, "Global", "override_user_agent", 
@@ -522,15 +504,14 @@ set_user_agent (KzProfile *profile, KzGtkWebcore *gtk_webcore)
 	{
 		build_user_agent(tmp_string, G_N_ELEMENTS(tmp_string));
 	}
-	OSB::Root *engine = 0;
-	engine = static_cast<OSB::Root*>(webi_get_internal(WEBI(gtk_webcore)));
 
-	engine->setUserAgentString(tmp_string);
+	settings->user_agent_string = g_strdup(tmp_string);
 }
 
 static void
 set_proxy (KzProfile *profile, KzGtkWebcore *gtk_webcore)
 {
+	WebiSettings *settings = KZ_GTK_WEBCORE_GET_PRIVATE(gtk_webcore)->settings;
 	gchar tmp_string[1024];
 	gchar *http_host, *https_host, *ftp_host;
 	guint http_port, https_port, ftp_port;
@@ -577,25 +558,18 @@ set_proxy (KzProfile *profile, KzGtkWebcore *gtk_webcore)
 			     NULL);
 	}
 
-	OSB::Root *engine = 0;
-	OSB::ProtocolDelegate *delegate = 0;
-	engine = static_cast<OSB::Root*>(webi_get_internal(WEBI(gtk_webcore)));
-
 	/* proxy for HTTP protocol */
-	delegate = engine->protocolDelegateForURL("http://");
-	if (delegate && http_host)
-		delegate->setProxy(http_host);
-	
+	if (http_host)
+		settings->http_proxy = g_strdup(http_host);
+#if 0
 	/* proxy for HTTPS protocol */
-	delegate = engine->protocolDelegateForURL("https://");
-	if (delegate && https_host)
-		delegate->setProxy(https_host);
+	if (https_host)
+		settings->https_proxy = g_strdup(https_host);
 	
 	/* proxy for FTP protocol */
-	delegate = engine->protocolDelegateForURL("ftp://");
-	if (delegate && ftp_host)
-		delegate->setProxy(ftp_host);
-	
+	if (ftp_host)
+		settings->ftp_proxy = g_strdup(ftp_host);
+#endif	
 	if (http_host)
 		g_free(http_host);
 	if (https_host)
@@ -607,22 +581,32 @@ set_proxy (KzProfile *profile, KzGtkWebcore *gtk_webcore)
 static void
 set_default_preferences (KzGtkWebcore *gtk_webcore)
 {
-	KzProfile *profile;
-
-	OSB::Preferences *preferences = get_osb_preferences(WEBI(gtk_webcore));
-	profile = kz_app_get_profile(kz_app);
+	WebiSettings *settings = KZ_GTK_WEBCORE_GET_PRIVATE(gtk_webcore)->settings;
+	KzProfile *profile = KZ_GET_GLOBAL_PROFILE;
 
 	gchar value[1024];
 	if (kz_profile_get_value(profile, "Language", "charset_default", 
 				&value, G_N_ELEMENTS(value),
 				KZ_PROFILE_VALUE_TYPE_STRING))
 	{
-		preferences->setDefaultTextEncoding(value);
+		settings->default_text_encoding = g_strdup(value);
 	}
 
 	set_user_agent(profile, gtk_webcore);
-	set_font_preferences (profile, preferences);
+	set_font_preferences (profile, gtk_webcore);
 	set_proxy(profile, gtk_webcore);
+	
+	settings->plugins_enabled = TRUE;
+	settings->javascript_enabled = TRUE;
+	settings->java_enabled = TRUE;
+	settings->autoload_images = TRUE;
+
+	webi_set_settings(WEBI(gtk_webcore), settings);
+#if 0
+	OSB::Features *features = get_osb_features(WEBI(gtk_webcore));
+	features->setToolbarsVisible(FALSE);
+	features->setStatusBarVisible(FALSE);
+#endif
 }
 
 static void
@@ -637,9 +621,35 @@ kz_gtk_webcore_init (KzGtkWebcore *gtk_webcore)
 
 	priv->button_press_time = 0;
 
+	priv->settings = g_new0(WebiSettings, 1);
+
 	set_default_preferences(gtk_webcore);
 	webi_set_emit_internal_status(WEBI(gtk_webcore), TRUE);
-	gtk_widget_show_all(GTK_WIDGET(gtk_webcore));
+
+	gtk_widget_show(GTK_WIDGET(gtk_webcore));
+}
+
+static void
+free_webi_settings (WebiSettings *settings)
+{
+	if (settings->default_text_encoding)
+		g_free((gchar*)settings->default_text_encoding);
+	if (settings->serif_font_family)
+		g_free((gchar*)settings->serif_font_family);
+	if (settings->sans_serif_font_family)
+		g_free((gchar*)settings->sans_serif_font_family);
+	if (settings->fixed_font_family)
+		g_free((gchar*)settings->fixed_font_family);
+	if (settings->standard_font_family)
+		g_free((gchar*)settings->standard_font_family);
+	if (settings->cursive_font_family)
+		g_free((gchar*)settings->cursive_font_family);
+	if (settings->fantasy_font_family)
+		g_free((gchar*)settings->fantasy_font_family);
+	if (settings->user_agent_string)
+		g_free((gchar*)settings->user_agent_string);
+	if (settings->http_proxy)
+		g_free((gchar*)settings->http_proxy);
 }
 
 static void
@@ -651,6 +661,13 @@ kz_gtk_webcore_dispose (GObject *object)
 		g_free(priv->link_message);
 	priv->link_message = NULL;
 
+	if (priv->settings)
+	{
+		free_webi_settings(priv->settings);
+		g_free(priv->settings);
+	}
+	priv->settings = NULL;
+
 	if (G_OBJECT_CLASS(kz_gtk_webcore_parent_class)->dispose)
 		G_OBJECT_CLASS(kz_gtk_webcore_parent_class)->dispose(object);
 }
@@ -760,12 +777,17 @@ static void
 kz_gtk_webcore_req_auth_prompt (Webi *webi, WebiAuthArgs* args)
 {
 	KzPromptDialog *prompt;
+	gchar *message;
 
 	g_return_if_fail(KZ_IS_GTK_WEBCORE(webi));
 
 	prompt= KZ_PROMPT_DIALOG(kz_prompt_dialog_new(TYPE_PROMPT_USER_PASS));
 
 	kz_prompt_dialog_set_title(prompt, _("Authentication"));
+	message = g_strdup_printf (_("Enter username and password for %s at %s"),
+				   args->realm, args->url);
+	kz_prompt_dialog_set_message_text(prompt, message);
+	g_free(message);
 	kz_prompt_dialog_run(prompt);
 
 	args->out_ok_pressed = kz_prompt_dialog_get_confirm_value(prompt);
@@ -779,12 +801,13 @@ kz_gtk_webcore_req_auth_prompt (Webi *webi, WebiAuthArgs* args)
 static Webi *
 kz_gtk_webcore_req_new_window (Webi *webi, const gchar *url)
 {
-	Webi *newgtk_webcore = NULL;
+	Webi *new_gtk_webcore = NULL;
 	g_return_val_if_fail(KZ_IS_GTK_WEBCORE(webi), NULL);
 	
-	g_signal_emit_by_name(webi, "kz-new-window", &newgtk_webcore);
+	g_signal_emit_by_name(webi, "kz-new-window", &new_gtk_webcore);
+	webi_load_url(new_gtk_webcore, url);
 
-	return newgtk_webcore;
+	return new_gtk_webcore;
 }
 
 static void
@@ -795,149 +818,11 @@ kz_gtk_webcore_close_window (Webi *webi)
 	gtk_widget_destroy(GTK_WIDGET(webi));
 }
 
-static void
-get_mouse_event_info(KzEmbedEventMouse **kzevent)
-{
-	GdkModifierType state = (GdkModifierType)0;
-	gint x, y;
-	KzEmbedEventMouse *ret;
-
-	gdk_window_get_pointer(NULL, &x, &y, &state);
-	ret = (KzEmbedEventMouse *) kz_embed_event_new(KZ_EMBED_EVENT_MOUSE);
-
-	ret->x = x;
-	ret->y = y;
-	if (state & GDK_SHIFT_MASK)
-        	ret->modifier |= KZ_SHIFT_KEY;
-	if (state & GDK_CONTROL_MASK)
-        	ret->modifier |= KZ_CTRL_KEY;
-	if (state & GDK_MOD1_MASK)
-        	ret->modifier |= KZ_ALT_KEY;
-	if (state & GDK_META_MASK)
-        	ret->modifier |= KZ_META_KEY;
-	
-	*kzevent = ret;
-}
-
-static void
-kz_gtk_webcore_mouse_over (Webi *webi,
-		     const gchar *link_title,
-		     const gchar *link_label,
-		     const gchar *link_url,
-		     const gchar *link_target)
-{
-	KzEmbedEventMouse *kzevent;
-	gint ret = FALSE;
-	KzGtkWebcorePrivate *priv;
-	g_return_if_fail(KZ_IS_GTK_WEBCORE(webi));
-
-	priv = KZ_GTK_WEBCORE_GET_PRIVATE(webi);
-	get_mouse_event_info(&kzevent);
-
-	if (!link_url)
-	{
-		if (priv->link_message)
-		{
-			g_free(priv->link_message);
-			priv->link_message = NULL;
-			g_signal_emit_by_name(webi, "kz-link-message");
-		}
-	}
-	else	
-	{
-		KzEmbedEvent *info = (KzEmbedEvent *) kzevent;
-		info->context = KZ_CONTEXT_LINK;
-		info->link = g_strdup(link_url);
-		info->linktext = g_strdup(link_label);
-
-		if (priv->link_message)
-			g_free(priv->link_message);
-
-		priv->link_message = g_strdup(link_url);
-
-		g_signal_emit_by_name(webi, "kz-link-message");
-	}
-
-	g_signal_emit_by_name(webi, "kz-dom-mouse-over",
-			      kzevent, &ret);
-	kz_embed_event_free((KzEmbedEvent *) kzevent);
-}
-
-#if GTK_WEBCORE_HAS_MOUSE_DOWN
-gboolean
-kz_gtk_webcore_mouse_down (Webi *webi,
-		     const gchar *link_url,
-		     guint button)
-{
-	KzEmbedEventMouse *kzevent;
-	gint ret = FALSE;
-	KzGtkWebcorePrivate *priv;
-	g_return_val_if_fail(KZ_IS_GTK_WEBCORE(webi), FALSE);
-
-	priv = KZ_GTK_WEBCORE_GET_PRIVATE(webi);
-	priv->button_press_time = GDK_CURRENT_TIME;
-
-	get_mouse_event_info(&kzevent);
-	kzevent->button = button - 1;
-
-	if (link_url)
-	{
-		KzEmbedEvent *info = (KzEmbedEvent *) kzevent;
-		info->context = KZ_CONTEXT_LINK;
-		info->link = g_strdup(link_url);
-	}
-
-	g_signal_emit_by_name(webi, "kz-dom-mouse-down",
-			      kzevent, &ret);
-	kz_embed_event_free((KzEmbedEvent *) kzevent);
-
-	return ret;
-}
-
 static gboolean
-kz_gtk_webcore_mouse_up (Webi *webi,
-		   const gchar *link_url,
-		   guint button)
-{
-	KzEmbedEventMouse *kzevent;
-	gint ret = FALSE;
-	KzGtkWebcorePrivate *priv;
-	g_return_val_if_fail(KZ_IS_GTK_WEBCORE(webi), FALSE);
-
-	priv = KZ_GTK_WEBCORE_GET_PRIVATE(webi);
-
-	get_mouse_event_info(&kzevent);
-	kzevent->button = button - 1;
-
-	g_signal_emit_by_name(webi, "kz-dom-mouse-up",
-			      kzevent, &ret);
-
-	if (!ret && GDK_CURRENT_TIME < priv->button_press_time + 1000)
-	{
-		if (link_url)
-		{
-			((KzEmbedEvent *)kzevent)->context = KZ_CONTEXT_LINK;
-			((KzEmbedEvent *)kzevent)->link = g_strdup(link_url);
-		}
-
-		g_signal_emit_by_name(webi, "kz-dom-mouse-click",
-				      kzevent, &ret);
-	}
-	priv->button_press_time = 0;
-
-	kz_embed_event_free((KzEmbedEvent *) kzevent);
-
-	return ret;
-}
-#endif
-
-static gboolean
-kz_gtk_webcore_set_cookie (Webi *webi, WebiCookie *cookie)
+kz_gtk_webcore_set_cookie (Webi *webi, const gchar *url, WebiCookie *cookie)
 {
 	g_return_val_if_fail(KZ_IS_GTK_WEBCORE(webi), FALSE);
 
-	cookie->out_accept_cookie = TRUE;
-
 	return TRUE;
 }
 
@@ -1116,14 +1001,12 @@ static gdouble
 kz_gtk_webcore_get_progress (KzEmbed *kzembed)
 {
 	gdouble progress;
-	KzGtkWebcore *gtk_webcore;
 	KzGtkWebcorePrivate *priv;
 
 	g_return_val_if_fail(KZ_IS_GTK_WEBCORE(kzembed), 0.0);
 
 	priv = KZ_GTK_WEBCORE_GET_PRIVATE (kzembed);
 
-	gtk_webcore = KZ_GTK_WEBCORE(kzembed);
 	if (priv->total_requests <= 0 ||
 	    priv->cur_requests <= 0)
 	{
@@ -1236,26 +1119,14 @@ kz_gtk_webcore_selection_is_collapsed (KzEmbed *kzembed)
 	return FALSE;
 }
 
-static OSB::Preferences *
-get_osb_preferences (Webi *webi)
-{
-	OSB::Root *engine = 0;
-	engine = static_cast<OSB::Root*>(webi_get_internal(webi));
-
-	OSB::Preferences *preferences = 0;
-	preferences = static_cast<OSB::Preferences*>(engine->preferences());
-
-	return preferences;
-}
-
 static gboolean
 kz_gtk_webcore_get_allow_javascript (KzEmbed *kzembed)
 {
 	g_return_val_if_fail(KZ_IS_GTK_WEBCORE(kzembed), FALSE);
 
-	OSB::Preferences *preferences = get_osb_preferences(WEBI(kzembed));
+	WebiSettings *settings = KZ_GTK_WEBCORE_GET_PRIVATE(kzembed)->settings;
 
-	return preferences->javaScriptEnabled() ? TRUE : FALSE;
+	return settings->javascript_enabled ? TRUE : FALSE;
 }
 
 static void
@@ -1263,9 +1134,10 @@ kz_gtk_webcore_set_allow_javascript (KzEmbed *kzembed, gboolean allow)
 {
 	g_return_if_fail(KZ_IS_GTK_WEBCORE(kzembed));
 
-	OSB::Preferences *preferences = get_osb_preferences(WEBI(kzembed));
+	WebiSettings *settings = KZ_GTK_WEBCORE_GET_PRIVATE(kzembed)->settings;
 
-	preferences->setJavaScriptEnabled(allow ? true : false);
+	settings->javascript_enabled = allow;
+	webi_set_settings(WEBI(kzembed), settings);
 }
 
 static gboolean
@@ -1273,9 +1145,9 @@ kz_gtk_webcore_get_allow_images (KzEmbed *kzembed)
 {
 	g_return_val_if_fail(KZ_IS_GTK_WEBCORE(kzembed), FALSE);
 
-	OSB::Preferences *preferences = get_osb_preferences(WEBI(kzembed));
+	WebiSettings *settings = KZ_GTK_WEBCORE_GET_PRIVATE(kzembed)->settings;
 
-	return preferences->willLoadImagesAutomatically() ? TRUE : FALSE;
+	return settings->autoload_images;
 }
 
 static void
@@ -1283,8 +1155,23 @@ kz_gtk_webcore_set_allow_images (KzEmbed *kzembed, gboolean allow)
 {
 	g_return_if_fail(KZ_IS_GTK_WEBCORE(kzembed));
 
-	OSB::Preferences *preferences = get_osb_preferences(WEBI(kzembed));
+	WebiSettings *settings = KZ_GTK_WEBCORE_GET_PRIVATE(kzembed)->settings;
 
-	preferences->setWillLoadImagesAutomatically(allow ? true : false);
+	settings->autoload_images = allow;
+	webi_set_settings(WEBI(kzembed), settings);
+}
+
+static gboolean
+kz_gtk_webcore_get_lock (KzEmbed *kzembed)
+{
+	g_return_val_if_fail(KZ_IS_GTK_WEBCORE(kzembed), FALSE);
+	return KZ_GTK_WEBCORE_GET_PRIVATE(kzembed)->lock;
+}
+
+static void
+kz_gtk_webcore_set_lock (KzEmbed *kzembed, gboolean lock)
+{
+	g_return_if_fail(KZ_IS_GTK_WEBCORE(kzembed));
+	KZ_GTK_WEBCORE_GET_PRIVATE(kzembed)->lock = lock;
 }
 
