@@ -20,9 +20,6 @@ typedef struct _KzStatusbarClass KzStatusbarClass;
 struct _KzStatusbar
 {
 	GtkHBox parent;
-
-	/* Kazehakase */
-	KzWindow *kz;
 };
 
 struct _KzStatusbarClass
