@@ -31,6 +31,9 @@
 #ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 #endif
+#ifdef HAVE_SYS_UTSNAME_H
+#  include <sys/utsname.h>
+#endif
 
 #include "utils.h"
 #include "glib-utils.h"
@@ -39,6 +42,10 @@
 #include "kazehakase.h"
 #include "kz-search.h"
 
+#ifdef G_OS_WIN32
+#  include <windows.h>
+#endif
+
 #define BUFFER_SIZE 1024
 
 #define TIME_STAMP_FORMAT "%ld,%s\n"
@@ -439,7 +446,7 @@ url_encode(const gchar* utf8src)
 
 
 gchar *
-complement_scheme (const gchar* url)
+kz_utils_complement_scheme (const gchar* url)
 {
 	gchar *file;
 
@@ -757,15 +764,14 @@ ensure_encode_string(const gchar *text,
 }
 
 GTime 
-thumbnail_get_last_modified (const gchar *uri)
+thumbnail_get_last_modified (const gchar *uri, EggPixbufThumbSize size)
 {
 	gchar *thumb_filename;
 	struct stat st;
 	int ret;
-	
-	thumb_filename = egg_pixbuf_get_thumb_filename(uri,
-						       EGG_PIXBUF_THUMB_LARGE);
-	
+
+	thumb_filename = egg_pixbuf_get_thumb_filename(uri, size);
+
 	ret = g_stat(thumb_filename, &st);
 	g_free(thumb_filename);
 
@@ -798,165 +804,6 @@ history_get_last_modified (const gchar *uri)
 		return 0;
 }
 
-#ifndef MOZ_NSICANVASRENDERINGCONTEXTINTERNAL_HAVE_GETINPUTSTREAM_
-typedef struct _KzPixbufConverter
-{
-	GdkPixbufLoader *loader;
-	gchar *uri;
-	gchar *filename;
-	time_t mtime;
-	EggPixbufThumbSize size;
-} KzPixbufConverter;
-
-
-static gboolean
-idle_dispose_converter(gpointer data)
-{
-	KzPixbufConverter *converter = data;
-
-	g_free(converter->uri);
-	g_free(converter->filename);
-	g_free(converter);
-
-	return FALSE;
-}
-
-static gboolean
-cb_io_in(GIOChannel *iochannel, GIOCondition condition,
-	 gpointer data)
-{
-	GIOStatus iostatus;
-	gsize bytes_read;
-	gchar buffer[BUFFER_SIZE];
-	KzPixbufConverter *converter = data;
-
-	if (condition & G_IO_ERR)
-	{
-		g_idle_add(idle_dispose_converter, converter);
-		return FALSE;
-	}
-
-	/* Read the data into our buffer */
-	iostatus = g_io_channel_read_chars(iochannel, buffer,
-					   sizeof(buffer),
-					   &bytes_read,
-					   NULL);
-
-	if (bytes_read)
-	{
-		gdk_pixbuf_loader_write(converter->loader,
-					(const guchar*)buffer, bytes_read,
-					NULL);
-	}
-
-	switch (iostatus)
-	{
-	 case G_IO_STATUS_EOF:
-	 {
-		GdkPixbuf *pixbuf;
-		pixbuf = gdk_pixbuf_loader_get_pixbuf(converter->loader);
-		if (pixbuf)
-		{
-			GdkPixbuf *rotate, *scale;
-
-			/* scale */
-			scale = gdk_pixbuf_scale_simple(pixbuf,
-						        KZ_THUMB_HEIGHT,
-							converter->size,
-						        GDK_INTERP_HYPER);
-
-			/* rotate image */
-			rotate = gdk_pixbuf_rotate_simple(scale,
-        						  GDK_PIXBUF_ROTATE_CLOCKWISE);
-			g_object_unref(scale);
-			/* save image */
-			if (rotate)
-			{
-				egg_pixbuf_add_thumbnail_data(rotate,
-							      converter->uri,
-							      converter->mtime,
-							      converter->size);
-				egg_pixbuf_save_thumbnail(rotate, NULL, NULL);
-				g_object_unref(rotate);
-			}
-		}
-		gdk_pixbuf_loader_close(converter->loader, NULL);
-		g_unlink(converter->filename);
-		g_idle_add(idle_dispose_converter, converter);
-
-		return FALSE;
-  	 }
-	 case G_IO_STATUS_NORMAL:
-		return TRUE;
-	 default:
-		g_idle_add(idle_dispose_converter, converter);
-		return FALSE;
-	}
-}
-
-
-void
-kz_utils_save_ps_as_thumbnail (const gchar *ps_file, const gchar *uri,
-			       time_t mtime, EggPixbufThumbSize size)
-{
-	const gchar *gs =
-		"gs -q -dNOPAUSE -dBATCH -r24 -sDEVICE=ppmraw -sOutputFile=- %s";
-	gchar *command;
-	gint argc, out;
-	gchar **argv = NULL;
-	GSpawnFlags flags;
-	GPid pid;
-	GIOChannel *io;
-	GdkPixbufLoader *loader;
-	KzPixbufConverter *converter;
-
-	command = g_strdup_printf(gs, ps_file);
-
-	g_shell_parse_argv(command,
-			   &argc,
-			   &argv,
-			   NULL);
-
-        /* Check whether ghostscript is installed or not */
-	if (g_find_program_in_path(argv[0]) == NULL)
-	{
-		g_warning("Can't find %s in your PATH.\n"
-			  "Currently kazehakase using gecko engine needs ghostscript to create thumbnails.\n", argv[0]);
-		return;
-	}
-
-	flags = G_SPAWN_SEARCH_PATH;
-	g_spawn_async_with_pipes(NULL,
-		      		 argv,
-				 NULL,
-		   		 flags,
-		      		 NULL,
-		      		 NULL,
-		      		 &pid,
-				 NULL,
-				 &out,
-				 NULL,
-		      		 NULL);
-	g_strfreev(argv);
-	g_free(command);
-
-	io = g_io_channel_unix_new(out);
-	g_io_channel_set_encoding(io, NULL, NULL);
-
-	loader = gdk_pixbuf_loader_new_with_type("pnm", NULL);
-	converter = g_new0(KzPixbufConverter, 1);
-	converter->loader = loader;
-	converter->uri = g_strdup(uri);
-	converter->filename = g_strdup(ps_file);
-	converter->mtime = mtime;
-	converter->size = size;
-
-	g_io_add_watch(io,
-		       G_IO_IN | G_IO_PRI | G_IO_ERR | G_IO_HUP,
-		       cb_io_in, converter);
-}
-#endif
-
 gboolean
 str_isdigit (const gchar *str)
 {
@@ -1062,6 +909,105 @@ kz_uri_encode_last_component (const gchar *uri)
 }
 
 #ifdef G_OS_WIN32
+static gchar *
+kz_win32_get_system_name (void)
+{
+	gchar *system = NULL;
+	OSVERSIONINFO version;
+
+	version.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
+	GetVersionEx(&version);
+
+	switch (version.dwPlatformId)
+	{
+	case VER_PLATFORM_WIN32s:
+		break;
+	case VER_PLATFORM_WIN32_WINDOWS:
+		if (version.dwMinorVersion == 0)
+		{
+			system = g_strdup("Windows 95");
+			break;
+		}
+
+		if (version.dwMinorVersion == 10)
+		{
+			system = g_strdup("Windows 98");
+			break;
+		}
+
+		if (version.dwMinorVersion == 90)
+		{
+			system = g_strdup("Windows Me");
+			break;
+		}
+
+		break;
+	case VER_PLATFORM_WIN32_NT:
+		if (version.dwMajorVersion == 5 &&
+		    version.dwMinorVersion == 0)
+		{
+			system = g_strdup_printf("Windows 2000 with %s",
+						 version.szCSDVersion);
+			break;
+		}
+
+		if (version.dwMajorVersion == 5 &&
+		    version.dwMinorVersion == 1)
+		{
+			system = g_strdup_printf("Windows XP %s",
+						 version.szCSDVersion);
+			break;
+		}
+
+		if (version.dwMajorVersion <= 4)
+		{
+			system = g_strdup_printf("Windows NT %ld.%ld with %s",
+						 version.dwMajorVersion,
+						 version.dwMinorVersion,
+						 version.szCSDVersion);
+			break;
+		}
+
+		break;
+	}
+
+	if (!system)
+		system = g_strdup_printf("Windows %ld.%ld",
+					 version.dwMajorVersion,
+					 version.dwMinorVersion);
+
+	return system;
+}
+#endif
+
+gchar *
+kz_utils_get_system_name (void)
+{
+	gchar *system = NULL;
+
+#ifdef HAVE_SYS_UTSNAME_H
+	{
+		struct utsname name;
+		if (uname(&name) >= 0)
+		{
+			system = g_strdup_printf("%s %s",
+						 name.sysname,
+						 name.machine);
+		}
+	}
+#endif
+
+#ifdef G_OS_WIN32
+	if (!system)
+		system = kz_win32_get_system_name();
+#endif
+
+	if (!system)
+		system = g_strdup("Unknown");
+
+	return system;
+}
+
 static gchar *win32_base_path = NULL;
 
 const gchar *
@@ -1070,8 +1016,10 @@ kz_win32_base_path (void)
 	if (win32_base_path)
 		return win32_base_path;
 
+#ifdef G_OS_WIN32
 	win32_base_path = g_win32_get_package_installation_directory(PACKAGE,
 								     NULL);
+#endif
+
 	return win32_base_path;
 }
-#endif
